@@ -5,7 +5,7 @@ use App::Sandy::Base 'class';
 
 extends 'App::Sandy::CLI::App';
 
-our $VERSION = '0.22'; # VERSION
+our $VERSION = '0.23'; # VERSION
 
 sub command_map {
 	genome        => 'App::Sandy::Command::Genome',
@@ -29,7 +29,7 @@ App::Sandy - App builder that simulates single-end and paired-end reads.
 
 =head1 VERSION
 
-version 0.22
+version 0.23
 
 =head1 SYNOPSIS
 
@@ -40,7 +40,7 @@ version 0.22
  Options:
   -h, --help               brief help message
   -u, --man                full documentation
- 
+
  Help commands:
   help                     show application or command-specific help
   man                      show application or command-specific documentation
@@ -60,25 +60,16 @@ version 0.22
 
 =head1 DESCRIPTION
 
-B<Sandy> is a bioinformatic tool that provides a simple engine to generate
-single-end/paired-end reads from a given fasta file. Many next-generation
-sequencing analyses rely on hypothetical models and principles that are
-not precisely satisfied in practice. Simulated data, which provides positive
-controls, would be a perfect way to overcome these difficulties. Here, we
-present Sandy, a straightforward, easy to use, fast, complete set of tools
-to generate synthetic second and third-generation sequencing reads. Sandy
-simulates whole genome sequencing, whole exome sequencing, RNAseq reads.
-Sandy presents also several features to the users manipulate the data, as
-well as well-organized database containing the ‘true’ information (based on
-the generated data) of the reads position into the genome, gene and transcript
-expression, sequencing errors, and the sequencing coverage. One of the most
-impressive features of Sandy is the power to simulate polymorphisms as snvs,
-indels and structural variations (e.g. gene duplication, retro-duplication,
-gene-fusion) along with the sequencing reads - with no need of further processing
-steps. Sandy can be used therefore for benchmarking results of a variety of
-pipelines in the genomics or transcriptomics, as well as in generating new
-hypotheses and helping in the best designing of sequencing projects, possibly
-optimizing time and costs.
+B<SANDY> is a bioinformatics tool that provides a simple engine to simulate next-generation
+sequencing for genomic and transcriptomic data. Simulated data works as experimental control
+- a key step to optimize NGS analysis - in comparison to hypothetical models. SANDY is a
+straightforward, easy-to-use, fast and highly customizable tool that generates reads requiring
+only a FASTA file as input. SANDY can simulate single/paired-end reads from both whole exome
+sequencing and RNA-seq as if produced from the most used second and third-generation sequencing
+platforms. SANDY’s reads can be simulated with genetic variations such as SNVs, indels and gene
+fusions. For customization purposes, SANDY have built-in (native) databases that can be easily
+extended with varying gene/transcript expression profiles, sequencing errors, sequencing
+coverages and genomic variations.
 
 =head1 AUTHORS
 
@@ -102,6 +93,10 @@ Helena B. Conceição <hconceicao@mochsl.org.br>
 
 =item *
 
+Rodrigo Barreiro <rbarreiro@mochsl.org.br>
+
+=item *
+
 Gabriela Guardia <gguardia@mochsl.org.br>
 
 =item *
